/*
 *  TOPPERS/SSP Kernel
 *      Smallest Set Profile Kernel
 * 
 *  Copyright (C) 2013,2014 by Naoki Saito
 *             Nagoya Municipal Industrial Research Institute, JAPAN
 * 
 *  上記著作権者は，以下の(1)〜(4)の条件を満たす場合に限り，本ソフトウェ
 *  ア（本ソフトウェアを改変したものを含む．以下同じ）を使用・複製・改
 *  変・再配布（以下，利用と呼ぶ）することを無償で許諾する．
 *  (1) 本ソフトウェアをソースコードの形で利用する場合には，上記の著作
 *      権表示，この利用条件および下記の無保証規定が，そのままの形でソー
 *      スコード中に含まれていること．
 *  (2) 本ソフトウェアを，ライブラリ形式など，他のソフトウェア開発に使
 *      用できる形で再配布する場合には，再配布に伴うドキュメント（利用
 *      者マニュアルなど）に，上記の著作権表示，この利用条件および下記
 *      の無保証規定を掲載すること．
 *  (3) 本ソフトウェアを，機器に組み込むなど，他のソフトウェア開発に使
 *      用できない形で再配布する場合には，次のいずれかの条件を満たすこ
 *      と．
 *    (a) 再配布に伴うドキュメント（利用者マニュアルなど）に，上記の著
 *        作権表示，この利用条件および下記の無保証規定を掲載すること．
 *    (b) 再配布の形態を，別に定める方法によって，TOPPERSプロジェクトに
 *        報告すること．
 *  (4) 本ソフトウェアの利用により直接的または間接的に生じるいかなる損
*      害からも，上記著作権者およびTOPPERSプロジェクトを免責すること．
 *      また，本ソフトウェアのユーザまたはエンドユーザからのいかなる理
 *      由に基づく請求からも，上記著作権者およびTOPPERSプロジェクトを
 *      免責すること．
 * 
 *  本ソフトウェアは，無保証で提供されているものである．上記著作権者お
 *  よびTOPPERSプロジェクトは，本ソフトウェアに関して，特定の使用目的
 *  に対する適合性も含めて，いかなる保証も行わない．また，本ソフトウェ
 *  アの利用により直接的または間接的に生じたいかなる損害に関しても，そ
 *  の責任を負わない．
 * 
 */

#ifndef TOPPERS_LPC812M101FDH20_H
#define TOPPERS_LPC812M101FDH20_H

/*
 *  CORTEX-M CPUの依存部のインクルード
 */
#include "armv6_m_gcc/arm_m.h"

/*
 *  プロセッサのエンディアン定義
 *    LPC812 はリトルエンディアン
 */
#define SIL_ENDIAN_LITTLE

/*
 *  割込み番号の最大値
 */
#define TMAX_INTNO   (47)

/*
 *  割込み優先度のビット幅
 */
#define TBITW_IPRI     (2)

/*
 *  割込みベクタ番号定義
 */
#define INT_SPI0    	(16)
#define INT_SPI1    	(17)

#define INT_UART0   	(19)
#define INT_UART1   	(20)
#define INT_UART2   	(21)

#define INT_I2C0    	(24)
#define INT_SCT     	(25)
#define INT_MRT     	(26)
#define INT_CMP     	(27)
#define INT_WDT     	(28)
#define INT_BOD     	(29)

#define INT_WKT     	(31)

#define INT_PININT0 	(40)
#define INT_PININT1		(41)
#define INT_PININT2		(42)
#define INT_PININT3		(43)
#define INT_PININT4		(44)
#define INT_PININT5		(45)
#define INT_PININT6		(46)
#define INT_PININT7		(47)


/*
 *  割込み優先度ビット幅中のサブ優先度のビット幅
 */
#define TBITW_SUBIPRI  0


/*
 * LPC812のレジスタ定義
 */
/* SYSCON */
#define TADR_SYSCON_BASE 	(0x40048000)

#define TOFFSET_SYSCON_SYSMEMREMAP 	(0x000)
#define TOFFSET_SYSCON_PRESETCTRL   	(0x004)
#define TOFFSET_SYSCON_SYSPLLCTRL  	(0x008)
#define TOFFSET_SYSCON_SYSPLLSTAT  	(0x00C)
#define TOFFSET_SYSCON_SYSOSCCTRL  	(0x020)
#define TOFFSET_SYSCON_WDTOSCCTRL  	(0x024)
#define TOFFSET_SYSCON_SYSRSTSTAT  	(0x030)
#define TOFFSET_SYSCON_SYSPLLCLKSEL	(0x040)
#define TOFFSET_SYSCON_SYSPLLCLKUEN	(0x044)
#define TOFFSET_SYSCON_MAINCLKSEL  	(0x070)
#define TOFFSET_SYSCON_MAINCLKUEN  	(0x074)
#define TOFFSET_SYSCON_SYSAHBCLKDIV	(0x078)
#define TOFFSET_SYSCON_SYSAHBCLKCTRL	(0x080)
#define TOFFSET_SYSCON_UARTCLKDIV   	(0x094)
#define TOFFSET_SYSCON_CLKOUTSEL    	(0x0E0)
#define TOFFSET_SYSCON_CLKOUTUEN    	(0x0E4)
#define TOFFSET_SYSCON_CLKOUTDIV    	(0x0E8)
#define TOFFSET_SYSCON_UARTFRGDIV  	(0x0F0)
#define TOFFSET_SYSCON_UARTFRGMULT  	(0x0F4)
#define TOFFSET_SYSCON_EXTTRACECMD  	(0x0FC)
#define TOFFSET_SYSCON_PIOPORCAP0  	(0x100)
#define TOFFSET_SYSCON_IOCONCLKDIV6	(0x134)
#define TOFFSET_SYSCON_IOCONCLKDIV5	(0x138)
#define TOFFSET_SYSCON_IOCONCLKDIV4	(0x13C)
#define TOFFSET_SYSCON_IOCONCLKDIV3	(0x140)
#define TOFFSET_SYSCON_IOCONCLKDIV2	(0x144)
#define TOFFSET_SYSCON_IOCONCLKDIV1	(0x148)
#define TOFFSET_SYSCON_IOCONCLKDIV0	(0x14C)
#define TOFFSET_SYSCON_BODCTRL     	(0x150)
#define TOFFSET_SYSCON_SYSTCKCAL   	(0x154)
#define TOFFSET_SYSCON_IRQLATENCY  	(0x170)
#define TOFFSET_SYSCON_NMISRC      	(0x174)
#define TOFFSET_SYSCON_PINTSEL0    	(0x178)
#define TOFFSET_SYSCON_PINTSEL1    	(0x17C)
#define TOFFSET_SYSCON_PINTSEL2    	(0x180)
#define TOFFSET_SYSCON_PINTSEL3    	(0x184)
#define TOFFSET_SYSCON_PINTSEL4    	(0x188)
#define TOFFSET_SYSCON_PINTSEL5    	(0x18C)
#define TOFFSET_SYSCON_PINTSEL6    	(0x190)
#define TOFFSET_SYSCON_PINTSEL7    	(0x194)
#define TOFFSET_SYSCON_STARTERP0   	(0x204)
#define TOFFSET_SYSCON_STARTERP1   	(0x214)
#define TOFFSET_SYSCON_PDSLEEPCFG   	(0x230)
#define TOFFSET_SYSCON_PDAWAKECFG  	(0x234)
#define TOFFSET_SYSCON_PDRUNCFG    	(0x238)
#define TOFFSET_SYSCON_DEVICE_ID   	(0x3F8)

#define TADR_SYSCON_SYSMEMREMAP 	(TADR_SYSCON_BASE + TOFFSET_SYSCON_SYSMEMREMAP )
#define TADR_SYSCON_PRESETCTRL   	(TADR_SYSCON_BASE + TOFFSET_SYSCON_PRESETCTRL   )
#define TADR_SYSCON_SYSPLLCTRL  	(TADR_SYSCON_BASE + TOFFSET_SYSCON_SYSPLLCTRL  )
#define TADR_SYSCON_SYSPLLSTAT  	(TADR_SYSCON_BASE + TOFFSET_SYSCON_SYSPLLSTAT  )
#define TADR_SYSCON_SYSOSCCTRL  	(TADR_SYSCON_BASE + TOFFSET_SYSCON_SYSOSCCTRL  )
#define TADR_SYSCON_WDTOSCCTRL  	(TADR_SYSCON_BASE + TOFFSET_SYSCON_WDTOSCCTRL  )
#define TADR_SYSCON_SYSRSTSTAT  	(TADR_SYSCON_BASE + TOFFSET_SYSCON_SYSRSTSTAT  )
#define TADR_SYSCON_SYSPLLCLKSEL	(TADR_SYSCON_BASE + TOFFSET_SYSCON_SYSPLLCLKSEL)
#define TADR_SYSCON_SYSPLLCLKUEN	(TADR_SYSCON_BASE + TOFFSET_SYSCON_SYSPLLCLKUEN)
#define TADR_SYSCON_MAINCLKSEL  	(TADR_SYSCON_BASE + TOFFSET_SYSCON_MAINCLKSEL  )
#define TADR_SYSCON_MAINCLKUEN  	(TADR_SYSCON_BASE + TOFFSET_SYSCON_MAINCLKUEN  )
#define TADR_SYSCON_SYSAHBCLKDIV	(TADR_SYSCON_BASE + TOFFSET_SYSCON_SYSAHBCLKDIV)
#define TADR_SYSCON_SYSAHBCLKCTRL	(TADR_SYSCON_BASE + TOFFSET_SYSCON_SYSAHBCLKCTRL)
#define TADR_SYSCON_UARTCLKDIV   	(TADR_SYSCON_BASE + TOFFSET_SYSCON_UARTCLKDIV  )
#define TADR_SYSCON_CLKOUTSEL    	(TADR_SYSCON_BASE + TOFFSET_SYSCON_CLKOUTSEL   )
#define TADR_SYSCON_CLKOUTUEN    	(TADR_SYSCON_BASE + TOFFSET_SYSCON_CLKOUTUEN   )
#define TADR_SYSCON_CLKOUTDIV    	(TADR_SYSCON_BASE + TOFFSET_SYSCON_CLKOUTDIV   )
#define TADR_SYSCON_UARTFRGDIV  	(TADR_SYSCON_BASE + TOFFSET_SYSCON_UARTFRGDIV  )
#define TADR_SYSCON_UARTFRGMULT  	(TADR_SYSCON_BASE + TOFFSET_SYSCON_UARTFRGMULT )
#define TADR_SYSCON_EXTTRACECMD  	(TADR_SYSCON_BASE + TOFFSET_SYSCON_EXTTRACECMD )
#define TADR_SYSCON_PIOPORCAP0  	(TADR_SYSCON_BASE + TOFFSET_SYSCON_PIOPORCAP0  )
#define TADR_SYSCON_IOCONCLKDIV6	(TADR_SYSCON_BASE + TOFFSET_SYSCON_IOCONCLKDIV6)
#define TADR_SYSCON_IOCONCLKDIV5	(TADR_SYSCON_BASE + TOFFSET_SYSCON_IOCONCLKDIV5)
#define TADR_SYSCON_IOCONCLKDIV4	(TADR_SYSCON_BASE + TOFFSET_SYSCON_IOCONCLKDIV4)
#define TADR_SYSCON_IOCONCLKDIV3	(TADR_SYSCON_BASE + TOFFSET_SYSCON_IOCONCLKDIV3)
#define TADR_SYSCON_IOCONCLKDIV2	(TADR_SYSCON_BASE + TOFFSET_SYSCON_IOCONCLKDIV2)
#define TADR_SYSCON_IOCONCLKDIV1	(TADR_SYSCON_BASE + TOFFSET_SYSCON_IOCONCLKDIV1)
#define TADR_SYSCON_IOCONCLKDIV0	(TADR_SYSCON_BASE + TOFFSET_SYSCON_IOCONCLKDIV0)
#define TADR_SYSCON_BODCTRL     	(TADR_SYSCON_BASE + TOFFSET_SYSCON_BODCTRL     )
#define TADR_SYSCON_SYSTCKCAL   	(TADR_SYSCON_BASE + TOFFSET_SYSCON_SYSTCKCAL   )
#define TADR_SYSCON_IRQLATENCY  	(TADR_SYSCON_BASE + TOFFSET_SYSCON_IRQLATENCY  )
#define TADR_SYSCON_NMISRC      	(TADR_SYSCON_BASE + TOFFSET_SYSCON_NMISRC      )
#define TADR_SYSCON_PINTSEL0    	(TADR_SYSCON_BASE + TOFFSET_SYSCON_PINTSEL0    )
#define TADR_SYSCON_PINTSEL1    	(TADR_SYSCON_BASE + TOFFSET_SYSCON_PINTSEL1    )
#define TADR_SYSCON_PINTSEL2    	(TADR_SYSCON_BASE + TOFFSET_SYSCON_PINTSEL2    )
#define TADR_SYSCON_PINTSEL3    	(TADR_SYSCON_BASE + TOFFSET_SYSCON_PINTSEL3    )
#define TADR_SYSCON_PINTSEL4    	(TADR_SYSCON_BASE + TOFFSET_SYSCON_PINTSEL4    )
#define TADR_SYSCON_PINTSEL5    	(TADR_SYSCON_BASE + TOFFSET_SYSCON_PINTSEL5    )
#define TADR_SYSCON_PINTSEL6    	(TADR_SYSCON_BASE + TOFFSET_SYSCON_PINTSEL6    )
#define TADR_SYSCON_PINTSEL7    	(TADR_SYSCON_BASE + TOFFSET_SYSCON_PINTSEL7    )
#define TADR_SYSCON_STARTERP0   	(TADR_SYSCON_BASE + TOFFSET_SYSCON_STARTERP0   )
#define TADR_SYSCON_STARTERP1   	(TADR_SYSCON_BASE + TOFFSET_SYSCON_STARTERP1   )
#define TADR_SYSCON_PDSLEEPCFG   	(TADR_SYSCON_BASE + TOFFSET_SYSCON_PDSLEEPCFG  )
#define TADR_SYSCON_PDAWAKECFG  	(TADR_SYSCON_BASE + TOFFSET_SYSCON_PDAWAKECFG  )
#define TADR_SYSCON_PDRUNCFG    	(TADR_SYSCON_BASE + TOFFSET_SYSCON_PDRUNCFG    )
#define TADR_SYSCON_DEVICE_ID   	(TADR_SYSCON_BASE + TOFFSET_SYSCON_DEVICE_ID   )


// PRESETCTRL
#define TBITPTN_SYSCON_PRESETCTRL_SPI0_RST_N   	(1 << 0)
#define TBITPTN_SYSCON_PRESETCTRL_SPI1_RST_N   	(1 << 1)
#define TBITPTN_SYSCON_PRESETCTRL_UARTFRG_RST_N	(1 << 2)
#define TBITPTN_SYSCON_PRESETCTRL_USART0_RST_N 	(1 << 3)
#define TBITPTN_SYSCON_PRESETCTRL_UART1_RST_N  	(1 << 4)
#define TBITPTN_SYSCON_PRESETCTRL_UART2_RST_N  	(1 << 5)
#define TBITPTN_SYSCON_PRESETCTRL_I2C_RST_N    	(1 << 6)
#define TBITPTN_SYSCON_PRESETCTRL_MRT_RST_N    	(1 << 7)
#define TBITPTN_SYSCON_PRESETCTRL_SCT_RST_N    	(1 << 8)
#define TBITPTN_SYSCON_PRESETCTRL_WKT_RST_N    	(1 << 9)
#define TBITPTN_SYSCON_PRESETCTRL_GPIO_RST_N   	(1 << 10)
#define TBITPTN_SYSCON_PRESETCTRL_FLASH_RST_N  	(1 << 11)
#define TBITPTN_SYSCON_PRESETCTRL_ACMP_RST_N   	(1 << 12)

// SYSPLLCTRL
#define TBITPTN_SYSCON_SYSPLLCTRL_MSEL 	(0x1F)
#define TBITPTN_SYSCON_SYSPLLCTRL_PSEL 	(0x11 << 5)
#define TBITPTN_SYSCON_SYSPLLCTRL_PSEL_P1 	(0x00 << 5)
#define TBITPTN_SYSCON_SYSPLLCTRL_PSEL_P2 	(0x01 << 5)
#define TBITPTN_SYSCON_SYSPLLCTRL_PSEL_P4 	(0x02 << 5)
#define TBITPTN_SYSCON_SYSPLLCTRL_PSEL_P8 	(0x03 << 5)

// SYSPLLSTAT
#define TBITPTN_SYSCON_SYSPLLSTAT_LOCK  	(1 << 0)

// SYSOSCCTRL
#define TBITPTN_SYSCON_SYSOSCCTRL_BYPASS   	(1 << 0)
#define TBITPTN_SYSCON_SYSOSCCTRL_FREQRANGE	(1 << 1)

// SYSPLLCLKSEL
#define TBITPTN_SYSCON_SYSPLLCLKSEL_SEL	(3 << 0)
#define TBITPTN_SYSCON_SYSPLLCLKSEL_SEL_IRC	(0 << 0)
#define TBITPTN_SYSCON_SYSPLLCLKSEL_SEL_SYSOSC	(1 << 0)
#define TBITPTN_SYSCON_SYSPLLCLKSEL_SEL_CLKIN	(3 << 0)

// SYSPLLCLKUEN
#define TBITPTN_SYSCON_SYSPLLCLKUEN_ENA	(1 << 0)

// MAINCLKSEL
#define TBITPTN_SYSCON_MAINCLKSEL_SEL  	(0x11 << 0)
#define TBITPTN_SYSCON_MAINCLKSEL_SEL_IRC  	(0x00 << 0)
#define TBITPTN_SYSCON_MAINCLKSEL_SEL_PLLIN  	(0x01 << 0)
#define TBITPTN_SYSCON_MAINCLKSEL_SEL_WDTOSC  	(0x02 << 0)
#define TBITPTN_SYSCON_MAINCLKSEL_SEL_PLLOUT  	(0x03 << 0)

// MAINCLKUEN
#define TBITPTN_SYSCON_MAINCLKUEN_ENA	(1 << 0)

// SYSAHBCLKDIV
#define TBITPTN_SYSCON_SYSAHBCLKDIV_DIV	(0xff << 0)

// SYSAHBCLKCTRL
#define TBITPTN_SYSCON_SYSAHBCLKCTRL_SYS  	(1 << 0)
#define TBITPTN_SYSCON_SYSAHBCLKCTRL_ROM  	(1 << 1)
#define TBITPTN_SYSCON_SYSAHBCLKCTRL_RAM  	(1 << 2)
#define TBITPTN_SYSCON_SYSAHBCLKCTRL_FLASHREG	(1 << 3)
#define TBITPTN_SYSCON_SYSAHBCLKCTRL_FLASH	(1 << 4)
#define TBITPTN_SYSCON_SYSAHBCLKCTRL_I2C  	(1 << 5)
#define TBITPTN_SYSCON_SYSAHBCLKCTRL_GPIO 	(1 << 6)
#define TBITPTN_SYSCON_SYSAHBCLKCTRL_SWM  	(1 << 7)
#define TBITPTN_SYSCON_SYSAHBCLKCTRL_SCT  	(1 << 8)
#define TBITPTN_SYSCON_SYSAHBCLKCTRL_WKT  	(1 << 9)
#define TBITPTN_SYSCON_SYSAHBCLKCTRL_MRT  	(1 << 10)
#define TBITPTN_SYSCON_SYSAHBCLKCTRL_SPI0 	(1 << 11)
#define TBITPTN_SYSCON_SYSAHBCLKCTRL_SPI1 	(1 << 12)
#define TBITPTN_SYSCON_SYSAHBCLKCTRL_CRC  	(1 << 13)
#define TBITPTN_SYSCON_SYSAHBCLKCTRL_UART0	(1 << 14)
#define TBITPTN_SYSCON_SYSAHBCLKCTRL_UART1	(1 << 15)
#define TBITPTN_SYSCON_SYSAHBCLKCTRL_UART2	(1 << 16)
#define TBITPTN_SYSCON_SYSAHBCLKCTRL_WWDT 	(1 << 17)
#define TBITPTN_SYSCON_SYSAHBCLKCTRL_IOCON	(1 << 18)
#define TBITPTN_SYSCON_SYSAHBCLKCTRL_ACMP 	(1 << 19)

// PDRUNCFG
#define TBITPTN_SYSCON_PDRUNCFG_IRCOUTPD	(1 << 0)
#define TBITPTN_SYSCON_PDRUNCFG_IRCPD   	(1 << 1)
#define TBITPTN_SYSCON_PDRUNCFG_FLASHPD 	(1 << 2)
#define TBITPTN_SYSCON_PDRUNCFG_BODPD   	(1 << 3)
#define TBITPTN_SYSCON_PDRUNCFG_SYSOSCPD	(1 << 5)
#define TBITPTN_SYSCON_PDRUNCFG_WDTOSCPD	(1 << 6)
#define TBITPTN_SYSCON_PDRUNCFG_SYSPLLPD	(1 << 7)
#define TBITPTN_SYSCON_PDRUNCFG_ACMP    	(1 << 15)



/* IOCON */
#define TADR_IOCON_BASE	(0x40044000)

#define TOFFSET_IOCON_PIO0_17 	(0x00)
#define TOFFSET_IOCON_PIO0_13 	(0x04)
#define TOFFSET_IOCON_PIO0_12 	(0x08)
#define TOFFSET_IOCON_PIO0_5  	(0x0C)
#define TOFFSET_IOCON_PIO0_4  	(0x10)
#define TOFFSET_IOCON_PIO0_3  	(0x14)
#define TOFFSET_IOCON_PIO0_2  	(0x18)
#define TOFFSET_IOCON_PIO0_11 	(0x1C)
#define TOFFSET_IOCON_PIO0_10 	(0x20)
#define TOFFSET_IOCON_PIO0_16 	(0x24)
#define TOFFSET_IOCON_PIO0_15 	(0x28)
#define TOFFSET_IOCON_PIO0_1  	(0x2C)
#define TOFFSET_IOCON_PIO0_9  	(0x34)
#define TOFFSET_IOCON_PIO0_8  	(0x38)
#define TOFFSET_IOCON_PIO0_7  	(0x3C)
#define TOFFSET_IOCON_PIO0_6  	(0x40)
#define TOFFSET_IOCON_PIO0_0  	(0x44)
#define TOFFSET_IOCON_PIO0_14 	(0x48)

#define TADR_IOCON_PIO0_17	(TADR_IOCON_BASE + TOFFSET_PIO0_17)
#define TADR_IOCON_PIO0_13	(TADR_IOCON_BASE + TOFFSET_PIO0_13)
#define TADR_IOCON_PIO0_12	(TADR_IOCON_BASE + TOFFSET_PIO0_12)
#define TADR_IOCON_PIO0_5 	(TADR_IOCON_BASE + TOFFSET_PIO0_5 )
#define TADR_IOCON_PIO0_4 	(TADR_IOCON_BASE + TOFFSET_PIO0_4 )
#define TADR_IOCON_PIO0_3 	(TADR_IOCON_BASE + TOFFSET_PIO0_3 )
#define TADR_IOCON_PIO0_2 	(TADR_IOCON_BASE + TOFFSET_PIO0_2 )
#define TADR_IOCON_PIO0_11	(TADR_IOCON_BASE + TOFFSET_PIO0_11)
#define TADR_IOCON_PIO0_10	(TADR_IOCON_BASE + TOFFSET_PIO0_10)
#define TADR_IOCON_PIO0_16	(TADR_IOCON_BASE + TOFFSET_PIO0_16)
#define TADR_IOCON_PIO0_15	(TADR_IOCON_BASE + TOFFSET_PIO0_15)
#define TADR_IOCON_PIO0_1 	(TADR_IOCON_BASE + TOFFSET_PIO0_1 )
#define TADR_IOCON_PIO0_9 	(TADR_IOCON_BASE + TOFFSET_PIO0_9 )
#define TADR_IOCON_PIO0_8 	(TADR_IOCON_BASE + TOFFSET_PIO0_8 )
#define TADR_IOCON_PIO0_7 	(TADR_IOCON_BASE + TOFFSET_PIO0_7 )
#define TADR_IOCON_PIO0_6 	(TADR_IOCON_BASE + TOFFSET_PIO0_6 )
#define TADR_IOCON_PIO0_0 	(TADR_IOCON_BASE + TOFFSET_PIO0_0 )
#define TADR_IOCON_PIO0_14	(TADR_IOCON_BASE + TOFFSET_PIO0_14)


// ビット定義
#define TBITPTN_IOCON_PIOx_MODE	(3 << 3)
#define TBITPTN_IOCON_PIOx_MODE_INACTIVE	(0 << 3)
#define TBITPTN_IOCON_PIOx_MODE_PULLDOWN	(1 << 3)
#define TBITPTN_IOCON_PIOx_MODE_PULLUP  	(2 << 3)
#define TBITPTN_IOCON_PIOx_MODE_REPEATER	(3 << 3)

#define TBITPTN_IOCON_PIOx_HYS	(1 << 5)
#define TBITPTN_IOCON_PIOx_INV	(1 << 6)
#define TBITPTN_IOCON_PIOx_OD 	(1 << 10)

#define TBITPTN_IOCON_PIOx_SMODE	(3 << 11)
#define TBITPTN_IOCON_PIOx_SMODE_BYPASS	(0 << 11)
#define TBITPTN_IOCON_PIOx_SMODE_1CLK 	(1 << 11)
#define TBITPTN_IOCON_PIOx_SMODE_2CLK 	(2 << 11)
#define TBITPTN_IOCON_PIOx_SMODE_3CLK 	(3 << 11)

#define TBITPTN_IOCON_PIOx_CLKDIV	(7 << 13)
#define TBITPTN_IOCON_PIOx_CLKDIV_CLKDIV0	(0 << 13)
#define TBITPTN_IOCON_PIOx_CLKDIV_CLKDIV1	(1 << 13)
#define TBITPTN_IOCON_PIOx_CLKDIV_CLKDIV2	(2 << 13)
#define TBITPTN_IOCON_PIOx_CLKDIV_CLKDIV3	(3 << 13)
#define TBITPTN_IOCON_PIOx_CLKDIV_CLKDIV4	(4 << 13)
#define TBITPTN_IOCON_PIOx_CLKDIV_CLKDIV5	(5 << 13)
#define TBITPTN_IOCON_PIOx_CLKDIV_CLKDIV6	(6 << 13)


/* SWM */
#define TADR_SWM_BASE	0x4000C000

#define TOFFSET_SWM_PINASSIGN0	(0x000)
#define TOFFSET_SWM_PINASSIGN1	(0x004)
#define TOFFSET_SWM_PINASSIGN2	(0x008)
#define TOFFSET_SWM_PINASSIGN3	(0x00C)
#define TOFFSET_SWM_PINASSIGN4	(0x010)
#define TOFFSET_SWM_PINASSIGN5	(0x014)
#define TOFFSET_SWM_PINASSIGN6	(0x018)
#define TOFFSET_SWM_PINASSIGN7	(0x01C)
#define TOFFSET_SWM_PINASSIGN8	(0x020)
#define TOFFSET_SWM_PINENABLE0	(0x1C0)

#define TADR_SWM_PINASSIGN0	(TADR_SWM_BASE + TOFFSET_SWM_PINASSIGN0)
#define TADR_SWM_PINASSIGN1	(TADR_SWM_BASE + TOFFSET_SWM_PINASSIGN1)
#define TADR_SWM_PINASSIGN2	(TADR_SWM_BASE + TOFFSET_SWM_PINASSIGN2)
#define TADR_SWM_PINASSIGN3	(TADR_SWM_BASE + TOFFSET_SWM_PINASSIGN3)
#define TADR_SWM_PINASSIGN4	(TADR_SWM_BASE + TOFFSET_SWM_PINASSIGN4)
#define TADR_SWM_PINASSIGN5	(TADR_SWM_BASE + TOFFSET_SWM_PINASSIGN5)
#define TADR_SWM_PINASSIGN6	(TADR_SWM_BASE + TOFFSET_SWM_PINASSIGN6)
#define TADR_SWM_PINASSIGN7	(TADR_SWM_BASE + TOFFSET_SWM_PINASSIGN7)
#define TADR_SWM_PINASSIGN8	(TADR_SWM_BASE + TOFFSET_SWM_PINASSIGN8)
#define TADR_SWM_PINENABLE0	(TADR_SWM_BASE + TOFFSET_SWM_PINENABLE0)

#define TBITPTN_SWM_PINENABLE0_ACMPI1EN 	(1 << 0)
#define TBITPTN_SWM_PINENABLE0_ACMPI2EN 	(1 << 0)
#define TBITPTN_SWM_PINENABLE0_SWCLKEN  	(1 << 2)
#define TBITPTN_SWM_PINENABLE0_SWDIOEN  	(1 << 3)
#define TBITPTN_SWM_PINENABLE0_XTALINEN 	(1 << 4)
#define TBITPTN_SWM_PINENABLE0_XTALOUTEN	(1 << 5)
#define TBITPTN_SWM_PINENABLE0_RESETEN  	(1 << 6)
#define TBITPTN_SWM_PINENABLE0_CLKIN    	(1 << 7)
#define TBITPTN_SWM_PINENABLE0_VDDCMP   	(1 << 8)


/* USART */
#define TADR_USART_BASE(index) 	(0x40064000 + (0x4000) * index)
#define TADR_USART0_BASE	TADR_USART_BASE(0)
#define TADR_USART1_BASE	TADR_USART_BASE(1)
#define TADR_USART2_BASE	TADR_USART_BASE(2)

#define TOFFSET_USART_CFG        	(0x00)
#define TOFFSET_USART_CTRL      	(0x04)
#define TOFFSET_USART_STAT       	(0x08)
#define TOFFSET_USART_INTENSET   	(0x0C)
#define TOFFSET_USART_INTENCLR   	(0x10)
#define TOFFSET_USART_RXDATA     	(0x14)
#define TOFFSET_USART_RXDATASTAT 	(0x18)
#define TOFFSET_USART_TXDATA     	(0x1C)
#define TOFFSET_USART_BRG        	(0x20)
#define TOFFSET_USART_INTSTAT    	(0x24)

#define TADR_USART_CFG(base)        	(base + TOFFSET_USART_CFG       )
#define TADR_USART_CTRL(base)        	(base + TOFFSET_USART_CTRL      )
#define TADR_USART_STAT(base)       	(base + TOFFSET_USART_STAT      )
#define TADR_USART_INTENSET(base)   	(base + TOFFSET_USART_INTENSET  )
#define TADR_USART_INTENCLR(base)   	(base + TOFFSET_USART_INTENCLR  )
#define TADR_USART_RXDATA(base)     	(base + TOFFSET_USART_RXDATA    )
#define TADR_USART_RXDATASTAT(base) 	(base + TOFFSET_USART_RXDATASTAT)
#define TADR_USART_TXDATA(base)     	(base + TOFFSET_USART_TXDATA    )
#define TADR_USART_BRG(base)        	(base + TOFFSET_USART_BRG       )
#define TADR_USART_INTSTAT(base)    	(base + TOFFSET_USART_INTSTAT   )

// CFG
#define TBITPTN_USART_CFG_ENABLE  	(1 << 0)
#define TBITPTN_USART_CFG_DATALEN 	(3 << 2)
#define TBITPTN_USART_CFG_DATALEN_7BIT	(0 << 2)
#define TBITPTN_USART_CFG_DATALEN_8BIT	(1 << 2)
#define TBITPTN_USART_CFG_DATALEN_9BIT	(2 << 2)
#define TBITPTN_USART_CFG_PARITYSEL  	(3 << 4)
#define TBITPTN_USART_CFG_PARITYSEL_NOPARITY	(0 << 4)
#define TBITPTN_USART_CFG_PARITYSEL_EVEN    	(2 << 4)
#define TBITPTN_USART_CFG_PARITYSEL_ODD     	(3 << 4)
#define TBITPTN_USART_CFG_STOPLEN 	(1 << 6)
#define TBITPTN_USART_CFG_STOPLEN_1BIT 	(0 << 6)
#define TBITPTN_USART_CFG_STOPLEN_2BIT 	(1 << 6)
#define TBITPTN_USART_CFG_CTSEN   	(1 << 9)
#define TBITPTN_USART_CFG_SYNCEN  	(1 << 11)
#define TBITPTN_USART_CFG_CLKPOL  	(1 << 12)
#define TBITPTN_USART_CFG_SYNCMST  	(1 << 14)
#define TBITPTN_USART_CFG_LOOP    	(1 << 15)

// STAT
#define TBITPTN_USART_STAT_RXRDY    	(1 << 0)
#define TBITPTN_USART_STAT_RXIDLE   	(1 << 1)
#define TBITPTN_USART_STAT_TXRDY    	(1 << 2)
#define TBITPTN_USART_STAT_TXIDLE   	(1 << 3)
#define TBITPTN_USART_STAT_CTS      	(1 << 4)
#define TBITPTN_USART_STAT_DELTACTS  	(1 << 5)
#define TBITPTN_USART_STAT_TXDISINT  	(1 << 6)
#define TBITPTN_USART_STAT_OVERRUNINT	(1 << 8)
#define TBITPTN_USART_STAT_RXBRK     	(1 << 10)
#define TBITPTN_USART_STAT_DELTARXBRK	(1 << 11)
#define TBITPTN_USART_STAT_START     	(1 << 12)
#define TBITPTN_USART_STAT_FRAMERRINT	(1 << 13)
#define TBITPTN_USART_STAT_PARITYERRINT	(1 << 14)
#define TBITPTN_USART_STAT_RXNOISEINT	(1 << 15)

// INTENSET
#define TBITPTN_USART_INTENSET_RXRDYEN    	(1 << 0)
#define TBITPTN_USART_INTENSET_TXRDYEN   	(1 << 2)
#define TBITPTN_USART_INTENSET_DELTACTSEN 	(1 << 5)
#define TBITPTN_USART_INTENSET_TXDISINTEN 	(1 << 6)
#define TBITPTN_USART_INTENSET_OVERRUNEN 	(1 << 8)
#define TBITPTN_USART_INTENSET_DELTARXBRKEN	(1 << 11)
#define TBITPTN_USART_INTENSET_STARTEN  	(1 << 12)
#define TBITPTN_USART_INTENSET_FRAMERREN 	(1 << 13)
#define TBITPTN_USART_INTENSET_PARITYERREN 	(1 << 14)
#define TBITPTN_USART_INTENSET_RXNOISEEN 	(1 << 15)

// INTENCLR
#define TBITPTN_USART_INTENCLR_RXRDYCLR 	(1 << 0)
#define TBITPTN_USART_INTENCLR_TXRDYCLR 	(1 << 2)
#define TBITPTN_USART_INTENCLR_DELTACTSCLR 	(1 << 5)
#define TBITPTN_USART_INTENCLR_TXDISINTCLR 	(1 << 6)
#define TBITPTN_USART_INTENCLR_OVERRUNCLR 	(1 << 8)
#define TBITPTN_USART_INTENCLR_DELTARXBRKCLR 	(1 << 11)
#define TBITPTN_USART_INTENCLR_STARTCLR 	(1 << 12)
#define TBITPTN_USART_INTENCLR_FRAMERRCLR 	(1 << 13)
#define TBITPTN_USART_INTENCLR_PARITYERRCLR 	(1 << 14)
#define TBITPTN_USART_INTENCLR_RXNOISECLR 	(1 << 15)


#endif /* TOPPERS_LPC812M101FDH20_H */
